@@ -61,7 +61,7 @@ delong.unpaired.test <- function(roc1, roc2) {
   return(c(t, df))
 }
 
-ci.auc.delong <- function(roc, conf.level) {
+ci_auc_delong <- function(roc, conf.level) {
   YR <- roc$controls # = C2, n, YRj
   XR <- roc$cases # = C1, m, XRi
 
@@ -96,7 +96,7 @@ ci.auc.delong <- function(roc, conf.level) {
 }
 
 # function to calculate the CI
-ci.delong.paired <- function(calcs, conf.level) {
+ci_delong_paired <- function(calcs, conf.level) {
 	
 	# Input calcs is a list generated by delong.paired.calculations().
 	# CI is calculated using the normally distributed pivot given in
