@@ -7,7 +7,7 @@ context("plot")
 # > manage_cases()
 
 test_that("plot draws correctly", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_basic_plot <- function() plot(r)
 	# S100b
 	r <- r.s100b
@@ -21,14 +21,14 @@ test_that("plot draws correctly", {
 })
 
 test_that("legacy.axis works correctly", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	r <- r.s100b
 	test_legacy.axis_plot <- function() plot(r, legacy.axes=TRUE)
 	expect_doppelganger("legacy.axes", test_legacy.axis_plot)
 })
 
 test_that("Advanced screenshot 1 works correctly", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_advanced_screenshot_1 <- function() {
 		plot(r.s100b.percent,
 			 reuse.auc = FALSE, partial.auc=c(100, 90), partial.auc.correct=TRUE, # define a partial AUC (pAUC)
@@ -53,16 +53,14 @@ test_that("Advanced screenshot 1 works correctly", {
 
 test_that("Advanced screenshot 2 works correctly", {
 	skip_slow()
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_advanced_screenshot_2 <- function() {
-		if (paste0(R.version$major, ".", R.version$minor) >= "3.6.0") {
-			RNGkind(sample.kind="Rounding")
-		}
+		RNGkind(sample.kind="Rejection")
 		set.seed(42) # For reproducible CI
-		rocobj <- plot.roc(aSAH$outcome, aSAH$s100b,
+		suppressMessages(rocobj <- plot.roc(aSAH$outcome, aSAH$s100b,
 						   main="Confidence intervals", percent=TRUE,
 						   ci=TRUE, # compute AUC (of AUC by default)
-						   print.auc=TRUE) # print the AUC (will contain the CI)
+						   print.auc=TRUE)) # print the AUC (will contain the CI)
 
 		ciobj <- ci.se(rocobj, progress = "none", # CI of sensitivity
 					   specificities=seq(0, 100, 5)) # over a select set of specificities
@@ -75,7 +73,7 @@ test_that("Advanced screenshot 2 works correctly", {
 
 
 test_that("Advanced screenshot 3 works correctly", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.4.0")
 	test_advanced_screenshot_3 <- function() {
 		plot(r.s100b.percent, main="Smoothing")
 		
@@ -98,18 +96,16 @@ test_that("Advanced screenshot 3 works correctly", {
 
 test_that("Advanced screenshot 4 works correctly", {
 	skip_slow()
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_advanced_screenshot_4 <- function() {
-		if (paste0(R.version$major, ".", R.version$minor) >= "3.6.0") {
-			RNGkind(sample.kind="Rounding")
-		}
+		RNGkind(sample.kind="Rejection")
 		set.seed(42) # For reproducible CI
-		rocobj <- plot.roc(aSAH$outcome, aSAH$s100b,
+		suppressMessages(rocobj <- plot.roc(aSAH$outcome, aSAH$s100b,
 						   main="Confidence intervals of specificity/sensitivity", percent=TRUE,
 						   ci=TRUE, of="se", # ci of sensitivity
 						   specificities=seq(0, 100, 5), # on a select set of specificities
 						   ci.type="shape", ci.col="#1c61b6AA", # plot the CI as a blue shape
-						   progress = "none") # hide progress bar
+						   progress = "none")) # hide progress bar
 		
 		plot(ci.sp(rocobj, sensitivities=seq(0, 100, 5), progress = "none"), # ci of specificity
 			 type="bars") # print this one as bars
@@ -121,25 +117,23 @@ test_that("Advanced screenshot 4 works correctly", {
 
 test_that("Advanced screenshot 5 works correctly", {
 	skip_slow()
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_advanced_screenshot_5 <- function() {
-		if (paste0(R.version$major, ".", R.version$minor) >= "3.6.0") {
-			RNGkind(sample.kind="Rounding")
-		}
+		RNGkind(sample.kind="Rejection")
 		set.seed(42) # For reproducible CI
-		plot.roc(aSAH$outcome, aSAH$s100b,
+		suppressMessages(plot.roc(aSAH$outcome, aSAH$s100b,
 				 main="Confidence interval of a threshold", percent=TRUE,
 				 ci=TRUE, of="thresholds", # compute AUC (of threshold)
 				 thresholds="best", # select the (best) threshold
 				 print.thres="best", # also highlight this threshold on the plot
-				 progress = "none") # hide progress bar
+				 progress = "none")) # hide progress bar
 	}
 	expect_doppelganger("advanced.screenshot.5", test_advanced_screenshot_5)
 })
 
 
 test_that("Advanced screenshot 6 works correctly", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_advanced_screenshot_6 <- function() {
 		plot(r.s100b.percent, main="Statistical comparison", col="#1c61b6")
 		lines(r.ndka.percent, col="#008600")
@@ -152,11 +146,11 @@ test_that("Advanced screenshot 6 works correctly", {
 
 
 test_that("plot and lines work with formula and subset", {
-	skip_if(getRversion() < 4.1)
+	skip_if(getRversion() < "4.1")
 	test_plot_formula <- function() {
-		plot.roc(outcome ~ ndka, data = aSAH, subset = gender == "Female", col="red")
-		lines.roc(outcome ~ ndka, data = aSAH)
-		lines.roc(outcome ~ ndka, data = aSAH, subset = gender == "Male", col="blue")
+		suppressMessages(plot.roc(outcome ~ ndka, data = aSAH, subset = gender == "Female", col="red"))
+		suppressMessages(lines.roc(outcome ~ ndka, data = aSAH))
+		suppressMessages(lines.roc(outcome ~ ndka, data = aSAH, subset = gender == "Male", col="blue"))
 	}
 	expect_doppelganger("plot_formula", test_plot_formula)
 })
